componenttools.yield_topmost_components_of_klass_grouped_by_type
================================================================

.. autofunction:: abjad.tools.componenttools.yield_topmost_components_of_klass_grouped_by_type.yield_topmost_components_of_klass_grouped_by_type
